summaryrefslogtreecommitdiffhomepage
path: root/test/iptables
diff options
context:
space:
mode:
authorNayana Bidari <nybidari@google.com>2020-01-10 09:05:25 -0800
committerNayana Bidari <nybidari@google.com>2020-01-10 09:05:25 -0800
commit9aeb053bbaf834aab5b716b8645996943262b525 (patch)
tree839ff02eaa9d01a1374254bc165f5b3995703446 /test/iptables
parent04abc9cf558930472605bf740a4333d6fafe5930 (diff)
Add tests for redirect port
Fix indentation and change function names.
Diffstat (limited to 'test/iptables')
-rw-r--r--test/iptables/iptables_test.go10
-rw-r--r--test/iptables/nat.go45
2 files changed, 27 insertions, 28 deletions
diff --git a/test/iptables/iptables_test.go b/test/iptables/iptables_test.go
index fce9247aa..05f27569f 100644
--- a/test/iptables/iptables_test.go
+++ b/test/iptables/iptables_test.go
@@ -178,14 +178,14 @@ func TestFilterInputDropDifferentUDPPort(t *testing.T) {
}
}
-func TestFilterNATRedirectUDPPort(t *testing.T) {
- if err := singleTest(FilterNATRedirectUDPPort{}); err != nil {
+func TestNATRedirectUDPPort(t *testing.T) {
+ if err := singleTest(NATRedirectUDPPort{}); err != nil {
t.Fatal(err)
}
}
-func TestFilterNATDropUDP(t *testing.T) {
- if err := singleTest(FilterNATDropUDP{}); err != nil {
- t.Fatal(err)
+func TestNATDropUDP(t *testing.T) {
+ if err := singleTest(NATDropUDP{}); err != nil {
+ t.Fatal(err)
}
}
diff --git a/test/iptables/nat.go b/test/iptables/nat.go
index 6deabf217..72c413af2 100644
--- a/test/iptables/nat.go
+++ b/test/iptables/nat.go
@@ -1,4 +1,4 @@
-// Copyright 2019 The gVisor Authors.
+// Copyright 2020 The gVisor Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
@@ -15,56 +15,55 @@
package iptables
import (
- "fmt"
- "net"
+ "fmt"
+ "net"
)
const (
- redirectPort = 42
+ redirectPort = 42
)
func init() {
- RegisterTestCase(FilterNATRedirectUDPPort{})
- RegisterTestCase(FilterNATDropUDP{})
+ RegisterTestCase(NATRedirectUDPPort{})
+ RegisterTestCase(NATDropUDP{})
}
-// FilterInputRedirectUDPPort tests that packets are redirected to different port.
-type FilterNATRedirectUDPPort struct{}
+// InputRedirectUDPPort tests that packets are redirected to different port.
+type NATRedirectUDPPort struct{}
// Name implements TestCase.Name.
-func (FilterNATRedirectUDPPort) Name() string {
- return "FilterNATRedirectUDPPort"
+func (NATRedirectUDPPort) Name() string {
+ return "NATRedirectUDPPort"
}
// ContainerAction implements TestCase.ContainerAction.
-func (FilterNATRedirectUDPPort) ContainerAction(ip net.IP) error {
- if err := filterTable("-t", "nat", "-A", "PREROUTING", "-p", "udp", "-j", "REDIRECT", "--to-ports",
+func (NATRedirectUDPPort) ContainerAction(ip net.IP) error {
+ if err := filterTable("-t", "nat", "-A", "PREROUTING", "-p", "udp", "-j", "REDIRECT", "--to-ports",
fmt.Sprintf("%d", redirectPort)); err != nil {
return err
}
if err := listenUDP(redirectPort, sendloopDuration); err != nil {
- return fmt.Errorf("packets on port %d should be allowed, but encountered an error: %v", redirectPort, err)
+ return fmt.Errorf("packets on port %d should be allowed, but encountered an error: %v", redirectPort, err)
}
-
return nil
}
// LocalAction implements TestCase.LocalAction.
-func (FilterNATRedirectUDPPort) LocalAction(ip net.IP) error {
- return sendUDPLoop(ip, acceptPort, sendloopDuration)
+func (NATRedirectUDPPort) LocalAction(ip net.IP) error {
+ return sendUDPLoop(ip, acceptPort, sendloopDuration)
}
-// FilterNATDropUDP tests that packets are not received in ports other than redirect port.
-type FilterNATDropUDP struct{}
+// NATDropUDP tests that packets are not received in ports other than redirect port.
+type NATDropUDP struct{}
// Name implements TestCase.Name.
-func (FilterNATDropUDP) Name() string {
- return "FilterNATDropUDP"
+func (NATDropUDP) Name() string {
+ return "NATDropUDP"
}
// ContainerAction implements TestCase.ContainerAction.
-func (FilterNATDropUDP) ContainerAction(ip net.IP) error {
+func (NATDropUDP) ContainerAction(ip net.IP) error {
if err := filterTable("-t", "nat", "-A", "PREROUTING", "-p", "udp", "-j", "REDIRECT", "--to-ports",
fmt.Sprintf("%d", redirectPort)); err != nil {
return err
@@ -78,6 +77,6 @@ func (FilterNATDropUDP) ContainerAction(ip net.IP) error {
}
// LocalAction implements TestCase.LocalAction.
-func (FilterNATDropUDP) LocalAction(ip net.IP) error {
- return sendUDPLoop(ip, acceptPort, sendloopDuration)
+func (NATDropUDP) LocalAction(ip net.IP) error {
+ return sendUDPLoop(ip, acceptPort, sendloopDuration)
}